# String Comparison

Text normalization for string comparison in Python.

## Requirements

This project requires Python 3.7+

## Installation

To install with pip

    pip install string_comparison

## Usage

    import string_comparison
    normalized = string_comparison.normalize("é")
    assert normalized == "e"
